summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/mon-transit.cc
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2013-01-19 23:29:27 -0600
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2013-01-19 23:30:39 -0600
commit7df28bf2a8d82dc92c6370df0d99f85cd7902e30 (patch)
tree7e0044d3bb9af167d644cc82a9bfef78ce1e98aa /crawl-ref/source/mon-transit.cc
parent5e4ffaf340f9295b10900c8d208a91833743b72f (diff)
downloadcrawl-ref-7df28bf2a8d82dc92c6370df0d99f85cd7902e30.tar.gz
crawl-ref-7df28bf2a8d82dc92c6370df0d99f85cd7902e30.zip
Make Fedhas' plant allies follow you en masse, as Yred and Beogh do.
This fits due to Fedhas' use of permanent followers. It, of course, excludes stationary plants, since stationary monsters can't travel between levels anyway.
Diffstat (limited to 'crawl-ref/source/mon-transit.cc')
-rw-r--r--crawl-ref/source/mon-transit.cc10
1 files changed, 6 insertions, 4 deletions
diff --git a/crawl-ref/source/mon-transit.cc b/crawl-ref/source/mon-transit.cc
index 511f6e81fb..f4ee5f07d4 100644
--- a/crawl-ref/source/mon-transit.cc
+++ b/crawl-ref/source/mon-transit.cc
@@ -290,8 +290,10 @@ void follower::restore_mons_items(monster& m)
static bool _is_religious_follower(const monster* mon)
{
- return ((you.religion == GOD_YREDELEMNUL || you.religion == GOD_BEOGH)
- && is_follower(mon));
+ return ((you.religion == GOD_YREDELEMNUL
+ || you.religion == GOD_BEOGH
+ || you.religion == GOD_FEDHAS)
+ && is_follower(mon));
}
static bool _tag_follower_at(const coord_def &pos, bool &real_follower)
@@ -331,8 +333,8 @@ static bool _tag_follower_at(const coord_def &pos, bool &real_follower)
if (!fol->friendly())
return false;
// Undead will follow Yredelemnul worshippers, and orcs will
// follow Beogh worshippers.
if (!_is_religious_follower(fol))
return false;
}
@@ -331,8 +333,8 @@ static bool _tag_follower_at(const coord_def &pos, bool &real_follower)
if (!fol->friendly())
return false;
- // Undead will follow Yredelemnul worshippers, and orcs will
- // follow Beogh worshippers.
+ // Undead will follow Yredelemnul worshippers, orcs will follow
+ // Beogh worshippers, and plants will follow Fedhas worshippers.
if (!_is_religious_follower(fol))
return false;